@@ -17,12 +17,12 @@
 from __future__ import annotations
 
 import re
+from functools import cached_property
 
 import google
 from google.api_core.exceptions import InvalidArgument, NotFound, PermissionDenied
 from google.cloud.secretmanager_v1 import SecretManagerServiceClient
 
-from airflow.compat.functools import cached_property
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.utils.log.logging_mixin import LoggingMixin
 
@@ -33,7 +33,7 @@ class _SecretManagerClient(LoggingMixin):
     """
     Retrieves Secrets object from Google Cloud Secrets Manager. This is a common class reused between
     SecretsManager and Secrets Hook that provides the shared authentication and verification mechanisms.
-    This class should not be used directly, use SecretsManager or SecretsHook instead
+    This class should not be used directly, use SecretsManager or SecretsHook instead.
 
 
     :param credentials: Credentials used to authenticate to GCP
@@ -50,6 +50,7 @@ class _SecretManagerClient(LoggingMixin):
     def is_valid_secret_name(secret_name: str) -> bool:
         """
         Returns true if the secret name is valid.
+
         :param secret_name: name of the secret
         :return:
         """
@@ -57,11 +58,11 @@ class _SecretManagerClient(LoggingMixin):
 
     @cached_property
     def client(self) -> SecretManagerServiceClient:
-        """Create an authenticated KMS client"""
+        """Create an authenticated KMS client."""
         _client = SecretManagerServiceClient(credentials=self.credentials, client_info=CLIENT_INFO)
         return _client
 
-    def get_secret(self, secret_id: str, project_id: str, secret_version: str = 'latest') -> str | None:
+    def get_secret(self, secret_id: str, project_id: str, secret_version: str = "latest") -> str | None:
         """
         Get secret value from the Secret Manager.
 
@@ -71,11 +72,11 @@ class _SecretManagerClient(LoggingMixin):
         """
         name = self.client.secret_version_path(project_id, secret_id, secret_version)
         try:
-            response = self.client.access_secret_version(name)
-            value = response.payload.data.decode('UTF-8')
+            response = self.client.access_secret_version(request={"name": name})
+            value = response.payload.data.decode("UTF-8")
             return value
         except NotFound:
-            self.log.error("Google Cloud API Call Error (NotFound): Secret ID %s not found.", secret_id)
+            self.log.debug("Google Cloud API Call Error (NotFound): Secret ID %s not found.", secret_id)
             return None
         except PermissionDenied:
             self.log.error(
