@@ -22,7 +22,7 @@ from typing import Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
-from google.cloud.language_v1 import LanguageServiceClient, enums
+from google.cloud.language_v1 import EncodingType, LanguageServiceClient
 from google.cloud.language_v1.types import (
     AnalyzeEntitiesResponse,
     AnalyzeEntitySentimentResponse,
@@ -68,7 +68,7 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
             gcp_conn_id=gcp_conn_id,
             impersonation_chain=impersonation_chain,
         )
-        self._conn = None
+        self._conn: LanguageServiceClient | None = None
 
     def get_conn(self) -> LanguageServiceClient:
         """
@@ -84,7 +84,7 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     def analyze_entities(
         self,
         document: dict | Document,
-        encoding_type: enums.EncodingType | None = None,
+        encoding_type: EncodingType | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -104,6 +104,8 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         """
         client = self.get_conn()
 
+        if isinstance(document, dict):
+            document = Document(document)
         return client.analyze_entities(
             document=document, encoding_type=encoding_type, retry=retry, timeout=timeout, metadata=metadata
         )
@@ -112,7 +114,7 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     def analyze_entity_sentiment(
         self,
         document: dict | Document,
-        encoding_type: enums.EncodingType | None = None,
+        encoding_type: EncodingType | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -132,6 +134,8 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         """
         client = self.get_conn()
 
+        if isinstance(document, dict):
+            document = Document(document)
         return client.analyze_entity_sentiment(
             document=document, encoding_type=encoding_type, retry=retry, timeout=timeout, metadata=metadata
         )
@@ -140,7 +144,7 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     def analyze_sentiment(
         self,
         document: dict | Document,
-        encoding_type: enums.EncodingType | None = None,
+        encoding_type: EncodingType | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -159,6 +163,8 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         """
         client = self.get_conn()
 
+        if isinstance(document, dict):
+            document = Document(document)
         return client.analyze_sentiment(
             document=document, encoding_type=encoding_type, retry=retry, timeout=timeout, metadata=metadata
         )
@@ -167,7 +173,7 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     def analyze_syntax(
         self,
         document: dict | Document,
-        encoding_type: enums.EncodingType | None = None,
+        encoding_type: EncodingType | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -187,6 +193,8 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         """
         client = self.get_conn()
 
+        if isinstance(document, dict):
+            document = Document(document)
         return client.analyze_syntax(
             document=document, encoding_type=encoding_type, retry=retry, timeout=timeout, metadata=metadata
         )
@@ -196,7 +204,7 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         self,
         document: dict | Document,
         features: dict | AnnotateTextRequest.Features,
-        encoding_type: enums.EncodingType = None,
+        encoding_type: EncodingType | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -218,6 +226,11 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         """
         client = self.get_conn()
 
+        if isinstance(document, dict):
+            document = Document(document)
+        if isinstance(features, dict):
+            features = AnnotateTextRequest.Features(features)
+
         return client.annotate_text(
             document=document,
             features=features,
@@ -248,4 +261,6 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         """
         client = self.get_conn()
 
+        if isinstance(document, dict):
+            document = Document(document)
         return client.classify_text(document=document, retry=retry, timeout=timeout, metadata=metadata)
