@@ -14,9 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-.. spelling::
+"""OS Login hooks.
 
+.. spelling:word-list::
     ImportSshPublicKeyResponse
     oslogin
 """
@@ -58,7 +58,7 @@ class OSLoginHook(GoogleBaseHook):
         self._conn: OsLoginServiceClient | None = None
 
     def get_conn(self) -> OsLoginServiceClient:
-        """Return OS Login service client"""
+        """Return OS Login service client."""
         if self._conn:
             return self._conn
 
