@@ -19,6 +19,7 @@
 from __future__ import annotations
 
 from copy import deepcopy
+from functools import cached_property
 from typing import Any, Callable, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -35,7 +36,6 @@ from google.cloud.vision_v1 import (
 from google.protobuf import field_mask_pb2
 from google.protobuf.json_format import MessageToDict
 
-from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
@@ -179,7 +179,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> str:
         """
         For the documentation see:
-        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateProductSetOperator`
+        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateProductSetOperator`.
         """
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}"
@@ -214,7 +214,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> dict:
         """
         For the documentation see:
-        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionGetProductSetOperator`
+        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionGetProductSetOperator`.
         """
         client = self.get_conn()
         name = ProductSearchClient.product_set_path(project_id, location, product_set_id)
@@ -238,7 +238,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> dict:
         """
         For the documentation see:
-        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionUpdateProductSetOperator`
+        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionUpdateProductSetOperator`.
         """
         client = self.get_conn()
 
@@ -271,7 +271,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> None:
         """
         For the documentation see:
-        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDeleteProductSetOperator`
+        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDeleteProductSetOperator`.
         """
         client = self.get_conn()
         name = ProductSearchClient.product_set_path(project_id, location, product_set_id)
@@ -292,7 +292,7 @@ class CloudVisionHook(GoogleBaseHook):
     ):
         """
         For the documentation see:
-        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateProductOperator`
+        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateProductOperator`.
         """
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}"
@@ -330,7 +330,7 @@ class CloudVisionHook(GoogleBaseHook):
     ):
         """
         For the documentation see:
-        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionGetProductOperator`
+        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionGetProductOperator`.
         """
         client = self.get_conn()
         name = ProductSearchClient.product_path(project_id, location, product_id)
@@ -354,7 +354,7 @@ class CloudVisionHook(GoogleBaseHook):
     ):
         """
         For the documentation see:
-        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionUpdateProductOperator`
+        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionUpdateProductOperator`.
         """
         client = self.get_conn()
 
@@ -385,7 +385,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> None:
         """
         For the documentation see:
-        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDeleteProductOperator`
+        :class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDeleteProductOperator`.
         """
         client = self.get_conn()
         name = ProductSearchClient.product_path(project_id, location, product_id)
@@ -407,7 +407,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> str:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateReferenceImageOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateReferenceImageOperator`.
         """
         client = self.get_conn()
         self.log.info("Creating ReferenceImage")
@@ -449,7 +449,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> None:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDeleteReferenceImageOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDeleteReferenceImageOperator`.
         """
         client = self.get_conn()
         self.log.info("Deleting ReferenceImage")
@@ -479,7 +479,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> None:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionAddProductToProductSetOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionAddProductToProductSetOperator`.
         """
         client = self.get_conn()
 
@@ -507,7 +507,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> None:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionRemoveProductFromProductSetOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionRemoveProductFromProductSetOperator`.
         """
         client = self.get_conn()
 
@@ -530,7 +530,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> dict:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionImageAnnotateOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionImageAnnotateOperator`.
         """
         client = self.annotator_client
 
@@ -551,7 +551,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> dict:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionImageAnnotateOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionImageAnnotateOperator`.
         """
         client = self.annotator_client
 
@@ -575,7 +575,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> dict:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDetectTextOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDetectTextOperator`.
         """
         client = self.annotator_client
 
@@ -605,7 +605,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> dict:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionTextDetectOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionTextDetectOperator`.
         """
         client = self.annotator_client
 
@@ -635,7 +635,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> dict:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDetectImageLabelsOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDetectImageLabelsOperator`.
         """
         client = self.annotator_client
 
@@ -665,7 +665,7 @@ class CloudVisionHook(GoogleBaseHook):
     ) -> dict:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDetectImageSafeSearchOperator`
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDetectImageSafeSearchOperator`.
         """
         client = self.annotator_client
 
