@@ -24,14 +24,14 @@ from typing import TYPE_CHECKING, Any, Sequence, Tuple
 from google.api_core.exceptions import AlreadyExists
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
-from google.cloud.vision_v1.types import (
+from google.cloud.vision_v1 import (
     AnnotateImageRequest,
-    FieldMask,
     Image,
     Product,
     ProductSet,
     ReferenceImage,
 )
+from google.protobuf.field_mask_pb2 import FieldMask  # type: ignore
 
 from airflow.providers.google.cloud.hooks.vision import CloudVisionHook
 from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
@@ -278,7 +278,7 @@ class CloudVisionUpdateProductSetOperator(GoogleCloudBaseOperator):
         location: str | None = None,
         product_set_id: str | None = None,
         project_id: str | None = None,
-        update_mask: dict | FieldMask = None,
+        update_mask: dict | FieldMask | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: MetaData = (),
@@ -303,6 +303,9 @@ class CloudVisionUpdateProductSetOperator(GoogleCloudBaseOperator):
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
         )
+
+        if isinstance(self.product_set, dict):
+            self.product_set = ProductSet(self.product_set)
         return hook.update_product_set(
             location=self.location,
             product_set_id=self.product_set_id,
@@ -650,7 +653,7 @@ class CloudVisionUpdateProductOperator(GoogleCloudBaseOperator):
         location: str | None = None,
         product_id: str | None = None,
         project_id: str | None = None,
-        update_mask: dict | FieldMask = None,
+        update_mask: dict | FieldMask | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: MetaData = (),
@@ -675,12 +678,13 @@ class CloudVisionUpdateProductOperator(GoogleCloudBaseOperator):
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
         )
+
         return hook.update_product(
             product=self.product,
             location=self.location,
             product_id=self.product_id,
             project_id=self.project_id,
-            update_mask=self.update_mask,
+            update_mask=self.update_mask,  # type: ignore
             retry=self.retry,
             timeout=self.timeout,
             metadata=self.metadata,
@@ -923,6 +927,9 @@ class CloudVisionCreateReferenceImageOperator(GoogleCloudBaseOperator):
                 gcp_conn_id=self.gcp_conn_id,
                 impersonation_chain=self.impersonation_chain,
             )
+
+            if isinstance(self.reference_image, dict):
+                self.reference_image = ReferenceImage(self.reference_image)
             return hook.create_reference_image(
                 location=self.location,
                 product_id=self.product_id,
@@ -1201,7 +1208,7 @@ class CloudVisionRemoveProductFromProductSetOperator(GoogleCloudBaseOperator):
 
 class CloudVisionDetectTextOperator(GoogleCloudBaseOperator):
     """
-    Detects Text in the image
+    Detects Text in the image.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1283,7 +1290,7 @@ class CloudVisionDetectTextOperator(GoogleCloudBaseOperator):
 
 class CloudVisionTextDetectOperator(GoogleCloudBaseOperator):
     """
-    Detects Document Text in the image
+    Detects Document Text in the image.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1364,7 +1371,7 @@ class CloudVisionTextDetectOperator(GoogleCloudBaseOperator):
 
 class CloudVisionDetectImageLabelsOperator(GoogleCloudBaseOperator):
     """
-    Detects Document Text in the image
+    Detects Document Text in the image.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1435,7 +1442,7 @@ class CloudVisionDetectImageLabelsOperator(GoogleCloudBaseOperator):
 
 class CloudVisionDetectImageSafeSearchOperator(GoogleCloudBaseOperator):
     """
-    Detects Document Text in the image
+    Detects Document Text in the image.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1509,7 +1516,7 @@ def prepare_additional_parameters(
 ) -> dict | None:
     """
     Creates additional_properties parameter based on language_hints, web_detection_params and
-    additional_properties parameters specified by the user
+    additional_properties parameters specified by the user.
     """
     if language_hints is None and web_detection_params is None:
         return additional_properties
